@@ -28,11 +28,14 @@ class CapturedPath:
         "Line is not connected to a GFA instance\n"+
         "Line: {}".format(self))
     retval = []
-    for i in range(len(self.segment_names) - 1):
-      retval.append(self.segment_names[i])
-      retval.append(self.links[i])
-    retval.append(self.segment_names[-1])
-    if len(self.segment_names) == len(self.links):
-      retval.append(self.links[-1])
+    if len(self.segment_names) == 1:
       retval.append(self.segment_names[0])
+    else:
+      for i in range(len(self.segment_names) - 1):
+        retval.append(self.segment_names[i])
+        retval.append(self.links[i])
+      retval.append(self.segment_names[-1])
+      if len(self.segment_names) == len(self.links):
+        retval.append(self.links[-1])
+        retval.append(self.segment_names[0])
     return retval
